mrc

Function mrc 

pub unsafe fn mrc<const CP: u32, const OP1: u32, const CRN: u32, const CRM: u32, const OP2: u32>() -> u32
This instruction moves one Coprocessor Register to a Register.

This function generates inline assembly and needs the instruction configuration during compilation time (i.e. as const).

The values of the constants required by this function should be defined by the coprocessor’s reference manual.

  • CP: The coprocessor’s index.
  • OP1: First optional operation for the coprocessor.
  • CRN: Coprocessor register N.
  • CRM: Coprocessor register M.
  • OP2: Second optional operation for the coprocessor.