mrrc

Function mrrc 

pub unsafe fn mrrc<const CP: u32, const OPC: u32, const CRM: u32>() -> (u32, u32)
This instruction moves two Coprocessor Registers to Registers.

This function generates inline assembly and needs the instruction configuration during compilation time (i.e. as const).

The values of the constants required by this function should be defined by the coprocessor’s reference manual.

  • CP: The coprocessor’s index.
  • OP1: First optional operation for the coprocessor.
  • CRM: Coprocessor register M.