Struct cortex_m::peripheral::icb::RegisterBlock
source · [−]Expand description
Register block
Fields
ictr: RO<u32>Interrupt Controller Type Register
The bottom four bits of this register give the number of implemented
interrupt lines, divided by 32. So a value of 0b0010 indicates 64
interrupts.
actlr: RW<u32>Auxiliary Control Register
This register is entirely implementation defined – the standard gives it an address, but does not define its role or contents.
cppwr: RW<u32>Coprocessor Power Control Register