_embedded_hal_blocking_serial_Write

Trait _embedded_hal_blocking_serial_Write 

pub trait _embedded_hal_blocking_serial_Write<Word> {
    type Error;

    // Required methods
    fn bwrite_all(&mut self, buffer: &[Word]) -> Result<(), Self::Error>;
    fn bflush(&mut self) -> Result<(), Self::Error>;
}
Write half of a serial interface (blocking variant)

Required Associated Types

type Error

The type of error that can occur when writing

Required Methods

fn bwrite_all(&mut self, buffer: &[Word]) -> Result<(), Self::Error>

Writes a slice, blocking until everything has been written

An implementation can choose to buffer the write, returning Ok(()) after the complete slice has been written to a buffer, but before all words have been sent via the serial interface. To make sure that everything has been sent, call bflush after this function returns.

fn bflush(&mut self) -> Result<(), Self::Error>

Block until the serial interface has sent all buffered words

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S, Word> Write<Word> for S
where S: Default<Word>, Word: Clone,

Source

type Error = <S as Write<Word>>::Error