Module psp

Module psp 

Process Stack Pointer support

Structs

Stack
A stack you can use as your Process Stack (PSP)
StackHandle
Represents access to a Stack

Functions

switch_to_privileged_psp
Switch to running on the Process Stack Pointer (PSP), but remain in privileged mode
switch_to_unprivileged_psp
Switch to unprivileged mode running on the Process Stack Pointer (PSP)