pub fn switch_to_privileged_psp(
psp_stack: StackHandle,
function: extern "C" fn() -> !,
) -> !Expand description
Switch to running on the Process Stack Pointer (PSP), but remain in privileged mode
pub fn switch_to_privileged_psp(
psp_stack: StackHandle,
function: extern "C" fn() -> !,
) -> !Switch to running on the Process Stack Pointer (PSP), but remain in privileged mode