switch_to_unprivileged_psp

Function switch_to_unprivileged_psp 

pub fn switch_to_unprivileged_psp(
    psp_stack: StackHandle,
    function: extern "C" fn() -> !,
) -> !
Switch to unprivileged mode running on the Process Stack Pointer (PSP)

In Unprivileged Mode, code can no longer perform privileged operations, such as disabling interrupts.