pub unsafe fn mcrr<const CP: u32, const OP1: u32, const CRM: u32>(
a: u32,
b: u32,
)Expand description
This instruction moves two Registers to Coprocessor Registers.
This function generates inline assembly and needs the instruction configuration
during compilation time (i.e. as const).
The values of the constants required by this function should be defined by the coprocessor’s reference manual.
- CP: The coprocessor’s index.
- OP1: First optional operation for the coprocessor.
- CRM: Coprocessor register M.