Processor core registers
The following registers can only be accessed in PRIVILEGED mode:
- BASEPRI
- CONTROL
- FAULTMASK
- MSP
- PRIMASK
The rest of registers (see list below) can be accessed in either, PRIVILEGED or UNPRIVILEGED, mode.
- APSR
- LR
- PC
- PSP
The following registers are NOT available on ARMv6-M devices
(thumbv6m-none-eabi):
- BASEPRI
- FAULTMASK
The following registers are only available for devices with an FPU:
- FPSCR
References
- Cortex-M* Devices Generic User Guide - Section 2.1.3 Core registers
Modules
- basepri
- Base Priority Mask Register
- basepri_
max - Base Priority Mask Register (conditional write)
- control
- Control register
- faultmask
- Fault Mask Register
- fpscr
- Floating-point Status Control Register
- msp
- Main Stack Pointer
- msplim
- Main Stack Pointer Limit Register
- primask
- Priority mask register
- psp
- Process Stack Pointer
- psplim
- Process Stack Pointer Limit Register